/**
 * Initialize the fero object with your projectId and apiKey
 * @param {string} projectId - your projectId
 * @param {string} apiKey - your apiKey - find it on https://gradfero.com/app/docs
 * @param {string} [sessionCookie=gradfero] - name of session cookie if passed on the frontend.
 */
export declare function createClient(projectId: string, apiKey: string, sessionCookie?: string): FeroTracking;
export declare class FeroTracking {
    projectId: string;
    private apiKey;
    sessionCookie: string;
    private getEventsUrl;
    /**
     * Initialize the fero object with your projectId and apiKey
     * @param {string} projectId - your projectId
     * @param {string} apiKey - your apiKey - find it on https://gradfero.com/app/docs
     * @param {string} [sessionCookie='gradfero'] - name of session cookie if passed on the frontend.
     */
    constructor(projectId: string, apiKey: string, sessionCookie?: string);
    /**
     * Lets you track an event.
     * @function
     * @param {string} eventName - name of the event (case insensitive) example: "purchase" or "signup"
     * @param {string} sessionId - Id of session, we'll attribute the event to this session.
     * @param {string} [eventId=uuid()] - Id of event, emit by using undefined or null. This will generate eventId for you. If your setup calls track muliple times, pass your own ID to prevent duplicate events.
     * @param {object} [data={}] - Any custom object of data you want to pass, this is searchable and filterable (soon).
     */
    event(eventName: string, sessionId: string, eventId?: string, data?: {}): Promise<{
        error: Error | null;
        response: object | null;
    }>;
}
